import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * A Firewall resource offers Palo Alto Networks next-generation firewall capabilities with built-in resiliency, scalability, and life-cycle management.
 *
 * @schema CfnNgfwProps
 */
export interface CfnNgfwProps {
    /**
     * @schema CfnNgfwProps#AppIdVersion
     */
    readonly appIdVersion?: string;
    /**
     * @schema CfnNgfwProps#AutomaticUpgradeAppIdVersion
     */
    readonly automaticUpgradeAppIdVersion?: boolean;
    /**
     * @schema CfnNgfwProps#Description
     */
    readonly description?: string;
    /**
     * @schema CfnNgfwProps#EndpointMode
     */
    readonly endpointMode: CfnNgfwPropsEndpointMode;
    /**
     * @schema CfnNgfwProps#FirewallName
     */
    readonly firewallName: string;
    /**
     * @schema CfnNgfwProps#RuleStackName
     */
    readonly ruleStackName?: string;
    /**
     * @schema CfnNgfwProps#SubnetMappings
     */
    readonly subnetMappings: string[];
    /**
     * @schema CfnNgfwProps#Tags
     */
    readonly tags?: any[];
    /**
     * @schema CfnNgfwProps#VpcId
     */
    readonly vpcId: string;
    /**
     * @schema CfnNgfwProps#LogDestinationConfigs
     */
    readonly logDestinationConfigs: LogProfileConfig[];
    /**
     * @schema CfnNgfwProps#CloudWatchMetricNamespace
     */
    readonly cloudWatchMetricNamespace?: string;
    /**
     * @schema CfnNgfwProps#ProgrammaticAccessToken
     */
    readonly programmaticAccessToken: string;
}
/**
 * Converts an object of type 'CfnNgfwProps' to JSON representation.
 */
export declare function toJson_CfnNgfwProps(obj: CfnNgfwProps | undefined): Record<string, any> | undefined;
/**
 * @schema CfnNgfwPropsEndpointMode
 */
export declare enum CfnNgfwPropsEndpointMode {
    /** ServiceManaged */
    SERVICE_MANAGED = "ServiceManaged",
    /** CustomerManaged */
    CUSTOMER_MANAGED = "CustomerManaged"
}
/**
 * Add Log profile config
 *
 * @schema LogProfileConfig
 */
export interface LogProfileConfig {
    /**
     * @schema LogProfileConfig#LogDestination
     */
    readonly logDestination: string;
    /**
     * @schema LogProfileConfig#LogDestinationType
     */
    readonly logDestinationType: LogProfileConfigLogDestinationType;
    /**
     * @schema LogProfileConfig#LogType
     */
    readonly logType: LogProfileConfigLogType;
}
/**
 * Converts an object of type 'LogProfileConfig' to JSON representation.
 */
export declare function toJson_LogProfileConfig(obj: LogProfileConfig | undefined): Record<string, any> | undefined;
/**
 * @schema LogProfileConfigLogDestinationType
 */
export declare enum LogProfileConfigLogDestinationType {
    /** S3 */
    S3 = "S3",
    /** CloudWatchLogs */
    CLOUD_WATCH_LOGS = "CloudWatchLogs",
    /** KinesisDataFirehose */
    KINESIS_DATA_FIREHOSE = "KinesisDataFirehose"
}
/**
 * @schema LogProfileConfigLogType
 */
export declare enum LogProfileConfigLogType {
    /** TRAFFIC */
    TRAFFIC = "TRAFFIC",
    /** DECRYPTION */
    DECRYPTION = "DECRYPTION",
    /** THREAT */
    THREAT = "THREAT"
}
/**
 * A CloudFormation `PaloAltoNetworks::CloudNGFW::NGFW`
 *
 * @cloudformationResource PaloAltoNetworks::CloudNGFW::NGFW
 * @stability external
 * @link https://github.com/aws-cloudformation/aws-cloudformation-rpdk.git
 */
export declare class CfnNgfw extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "PaloAltoNetworks::CloudNGFW::NGFW";
    /**
     * Resource props.
     */
    readonly props: CfnNgfwProps;
    /**
     * Create a new `PaloAltoNetworks::CloudNGFW::NGFW`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnNgfwProps);
}
